@@ -111,7 +111,7 @@ class IDLMarker(object):
             # The "NamedConstructor" Name already got markup up, so ignore this one.
             return (None, None)
 
-        return ('<a class=n data-link-type="idl-name">', '</a>')
+        return ('<a data-link-type="idl-name">', '</a>')
 
     def markup_keyword(self, text, construct):
         # Fires on the various "keywords" of WebIDL -
@@ -125,6 +125,17 @@ class IDLMarker(object):
             else:
                 # Otherwise, you *can* point to/dfn stringification behavior if you want.
                 return ("<idl data-export data-idl-type=dfn data-idl-for='{0}' data-lt='stringification behavior' id='{0}-stringification-behavior'>".format(construct.parent.full_name), "</idl>")
+        # The remaining built-in types that aren't covered by a more specific function.
+        builtinTypes = {
+            "any":"interface",
+            "sequence":"dfn",
+            "record":"dfn",
+            "Promise":"interface",
+            "FrozenArray":"interface",
+            "ObservableArray":"interface",
+        }
+        if text in builtinTypes:
+            return (f'<a data-link-spec=webidl data-link-type="{builtinTypes[text]}">', '</a>')
         return (None, None)
 
     def markup_name(self, text, construct):
@@ -267,7 +278,11 @@ def markupIDL(doc):
                 replaceNode(span, *contents)
         return
     if highlightingOccurred:
-        doc.extraStyles['style-syntax-highlighting'] += "pre.idl.highlight { color: #708090; }"
+        doc.extraStyles['style-syntax-highlighting'] += '''
+            pre.idl.highlight {
+                background: var(--borderedblock-bg, var(--def-bg));
+            }
+            '''
 
 
 def processIDL(doc):
